Class VertxServer

java.lang.Object
io.jooby.Server.Base
io.jooby.netty.NettyServer
io.jooby.vertx.VertxServer
All Implemented Interfaces:
io.jooby.Server

public class VertxServer extends io.jooby.netty.NettyServer
Just a NettyServer server with a shared event loop group from Vertx.

The following services are accessible from application registry:

  • Vertx
  • EventBus
  • FileSystem
Since:
4.0.8
Author:
edgar
  • Nested Class Summary

    Nested classes/interfaces inherited from interface io.jooby.Server

    io.jooby.Server.Base
  • Constructor Summary

    Constructors
    Constructor
    Description
    Creates a new vertx server with prefer native transport on and event loop size matching the number of ioThreads from server options.
    VertxServer(io.vertx.core.Vertx vertx)
    Creates a new vertx server.
    VertxServer(io.vertx.core.VertxOptions options)
    Creates a new vertx server.
  • Method Summary

    Modifier and Type
    Method
    Description
     
    io.jooby.Server
    init(io.jooby.Jooby application)
     
    io.jooby.Server
     

    Methods inherited from class io.jooby.netty.NettyServer

    getOutputFactory, setSingleEventLoopGroup, start

    Methods inherited from class io.jooby.Server.Base

    getOptions, setOptions

    Methods inherited from class java.lang.Object

    equals, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait

    Methods inherited from interface io.jooby.Server

    getLoggerOff
  • Constructor Details

    • VertxServer

      public VertxServer(@NonNull io.vertx.core.Vertx vertx)
      Creates a new vertx server.
      Parameters:
      vertx - Use the provided vertx instance.
    • VertxServer

      public VertxServer(@NonNull io.vertx.core.VertxOptions options)
      Creates a new vertx server.
      Parameters:
      options - Use the provided vertx options.
    • VertxServer

      public VertxServer()
      Creates a new vertx server with prefer native transport on and event loop size matching the number of ioThreads from server options.
  • Method Details

    • init

      public io.jooby.Server init(@NonNull io.jooby.Jooby application)
    • getName

      public String getName()
      Specified by:
      getName in interface io.jooby.Server
      Overrides:
      getName in class io.jooby.netty.NettyServer
    • stop

      public io.jooby.Server stop()
      Specified by:
      stop in interface io.jooby.Server
      Overrides:
      stop in class io.jooby.netty.NettyServer