Index

A G I S V 
All Classes and Interfaces|All Packages

A

apply(Route.Handler) - Method in class io.jooby.vertx.VertxHandler
 

G

getName() - Method in class io.jooby.vertx.VertxServer
 

I

init(Jooby) - Method in class io.jooby.vertx.VertxServer
 
install(Jooby) - Method in class io.jooby.vertx.VertxModule
 
io.jooby.vertx - module io.jooby.vertx
Vertx module
io.jooby.vertx - package io.jooby.vertx
 

S

stop() - Method in class io.jooby.vertx.VertxServer
 

V

vertx() - Static method in class io.jooby.vertx.VertxHandler
 
VertxHandler - Class in io.jooby.vertx
A handler/filter that know how to handle Vertx types like: Future Promise AsyncFile
VertxHandler() - Constructor for class io.jooby.vertx.VertxHandler
 
VertxModule - Class in io.jooby.vertx
A Vertx module.
VertxModule() - Constructor for class io.jooby.vertx.VertxModule
Creates a new vertx module.
VertxModule(Vertx) - Constructor for class io.jooby.vertx.VertxModule
Creates a new vertx module.
VertxModule(VertxOptions) - Constructor for class io.jooby.vertx.VertxModule
Creates a new vertx module.
VertxModule(Function<VertxOptions, Future<Vertx>>) - Constructor for class io.jooby.vertx.VertxModule
Creates a new vertx module.
VertxModule(Supplier<Future<Vertx>>) - Constructor for class io.jooby.vertx.VertxModule
Creates a new vertx module.
VertxServer - Class in io.jooby.vertx
Just a NettyServer server with a shared event loop group from Vertx.
VertxServer() - Constructor for class io.jooby.vertx.VertxServer
Creates a new vertx server with prefer native transport on and event loop size matching the number of ioThreads from server options.
VertxServer(Vertx) - Constructor for class io.jooby.vertx.VertxServer
Creates a new vertx server.
VertxServer(VertxOptions) - Constructor for class io.jooby.vertx.VertxServer
Creates a new vertx server.
A G I S V 
All Classes and Interfaces|All Packages